function PD:LoadOptions()
	local Dewdrop = AceLibrary:HasInstance("Dewdrop-2.0") and AceLibrary("Dewdrop-2.0")
	local Waterfall = AceLibrary:HasInstance("Waterfall-1.0") and AceLibrary("Waterfall-1.0")
	local SharedMedia = LibStub and LibStub:GetLibrary("LibSharedMedia-2.0", true)

	self.options = {
		type = "group",
		args = {
			color = {
				name = PD.L["Color"], desc = PD.L["Color options"], type = "group",
				args = {
					damag = {
						name = PD.L["Damage"], desc = PD.L["Color for the damage amount"], type = "color", order = 1,
						get = function()
							return PD.db.profile.colorDamag.r, PD.db.profile.colorDamag.g, PD.db.profile.colorDamag.b
						end,
						set = function(r, g, b)
							PD.db.profile.colorDamag.r, PD.db.profile.colorDamag.g, PD.db.profile.colorDamag.b = r, g, b
							self:UpdateColors()
						end,
					},
					typed = {
						name = PD.L["Type"], desc = PD.L["Color for the damage type"], type = "color", order = 2,
						get = function()
							return PD.db.profile.colorTyped.r, PD.db.profile.colorTyped.g, PD.db.profile.colorTyped.b
						end,
						set = function(r, g, b)
							PD.db.profile.colorTyped.r, PD.db.profile.colorTyped.g, PD.db.profile.colorTyped.b = r, g, b
							self:UpdateColors()
						end,
					}
				}
			},
			display = {
				name = PD.L["Display"], desc = PD.L["Miscellaneous display options"], type = "group",
				args = {
					damtype = {
						name = PD.L["Type"], desc = PD.L["What do you want to watch"], type = "text",
						validate = {
							["1"] = PD.L["Physical Damage"],
							["2"] = PD.L["Holy Damage"],
							["3"] = PD.L["Fire Damage"],
							["4"] = PD.L["Nature Damage"],
							["5"] = PD.L["Frost Damage"],
							["6"] = PD.L["Shadow Damage"],
							["7"] = PD.L["Arcane Damage"],
							["8"] = PD.L["Healing Power"],
							["9"] = PD.L["Attack Power"],
							["10"] = PD.L["Ranged Attack Power"]
						},
						get = function() return PD.db.char.damtype end,
						set = function(v)
							PD.db.char.damtype = v
						end
					},
					align = {
						name = PD.L["Horizontal Alignment"], desc = PD.L["The horizontal alignment of the text."], type = "text",
						validate = {
							["CENTER"] = PD.L["Center"],
							["LEFT"] = PD.L["Left"],
							["RIGHT"] = PD.L["Right"]
						},
						get = function() return PD.db.profile.align end,
						set = function(v)
							PD.db.profile.align = v
							self:UpdatePosition()
						end
					},
				}
			},
			font = {
				name = PD.L["Font"], desc = PD.L["Font options"], type = "group",
				args = {
					outline = {
						name = PD.L["Outline"],
						desc = PD.L["Show an outline around the text"],
						type = "text",
						validate = {
							["NONE"] = PD.L["None"],
							["OUTLINE"] = PD.L["Thin"],
							["THICKOUTLINE"] = PD.L["Thick"]
						},
						get = function() return PD.db.profile.fontOutline end,
						set = function(v)
							PD.db.profile.fontOutline = v
							self:UpdateFonts()
						end
					},
					shadow = {
						name = PD.L["Shadow"], desc = PD.L["Show a shadow on the text"], type = "toggle",
						get = function() return PD.db.profile.fontShadow end,
						set = function(v)
							PD.db.profile.fontShadow = v
							self:UpdateFonts()
						end
					},
					size = {
						name = PD.L["Size"], desc = PD.L["Font size options"], type = "group",
						args = {
							damag = {
								name = PD.L["Damage"], desc = PD.L["Font size for the damage"], type = "range", order = 1,
								min = 8, max = 50, step = 1, bigStep = 4,
								get = function() return PD.db.profile.fontSizeDamag end,
								set = function(v)
									PD.db.profile.fontSizeDamag = v
									self:UpdateFonts()
									self:UpdatePosition()
								end
							},
							typed = {
								name = PD.L["Type"], desc = PD.L["Font size for the type"], type = "range", order = 2,
								min = 8, max = 32, step = 1, bigStep = 4,
								get = function() return PD.db.profile.fontSizeTyped end,
								set = function(v)
									PD.db.profile.fontSizeTyped = v
									self:UpdateFonts()
									self:UpdatePosition()
								end
							}
						}
					}
				}
			},
			frame = {
				name = PD.L["Position"], desc = PD.L["Frame position options"], type = "group",
				args = {
					pos = {
						name = PD.L["Anchor Point"], desc = PD.L["Anchor the frame to this point of the screen"], type = "text",
						validate = {
							["BOTTOM"] = PD.L["Bottom Edge"],
							["BOTTOMLEFT"] = PD.L["Bottom Left Corner"],
							["BOTTOMRIGHT"] = PD.L["Bottom Right Corner"],
							["CENTER"] = PD.L["Center"],
							["LEFT"] = PD.L["Left Edge"],
							["TOP"] = PD.L["Top Edge"],
							["TOPLEFT"] = PD.L["Top Left Corner"],
							["TOPRIGHT"] = PD.L["Top Right Corner"],
							["RIGHT"] = PD.L["Right Edge"],
						},
						get = function() return PD.db.profile.pos end,
						set = function(v)
							PD.db.profile.pos = v
							self:UpdatePosition()
						end
					},
					X = {
						name = PD.L["Horizontal offset"], desc = PD.L["Horizontal distance to place the frame relative to its anchor point"], type = "range",
						min = -800, max = 1600, step = 1, bigStep = 5,
						get = function() return PD.db.profile.posX end,
						set = function(v)
							PD.db.profile.posX = v
							self:UpdatePosition()
						end
					},
					Y = {
						name = PD.L["Vertical offset"], desc = PD.L["Vertical distance to place the frame relative to its anchor point"], type = "range",
						min = -600, max = 1200, step = 1, bigStep = 5,
						get = function() return PD.db.profile.posY end,
						set = function(v)
							PD.db.profile.posY = v
							self:UpdatePosition()
						end
					}
				}
			},
		}
	}

	self:RegisterChatCommand("/powerd", self.options, "PD")

	if SharedMedia then
		self.options.args.font.args.face = {
			name = PD.L["Typeface"], desc = PD.L["Typeface to use"], type = "text",
			validate = SharedMedia:List("font"),
			get = function() return PD.db.profile.fontFace end,
			set = function(v)
				PD.db.profile.fontFace = v
				self:UpdateFonts()
			end
		}
	end

	if Dewdrop then
		self.options.args.menu = {
			name = PD.L["Dropdown Menu"], desc = PD.L["Open a dropdown configuration menu"], type = "execute",
			guiHidden = true, wfHidden = true,
			func = function() Dewdrop:Open("PD", "children", function() Dewdrop:FeedAceOptionsTable(self.options) end) end
		}
	end

	if Waterfall then
		Waterfall:Register("PD", "aceOptions", self.options, "title", "PD", "treeLevels", 2, "colorR", 0.0, "colorG", 0.86, "colorB", 0.73)
		self.options.args.options = {
			name = PD.L["GUI Menu"], desc = PD.L["Open a GUI configuration window"], type = "execute",
			guiHidden = true, wfHidden = true,
			func = function() Waterfall:Open("PD") end
		}
	end
end